
# Table of Contents

-   [Sensors](#org0df8c8f)
    -   [IMU](#orgf19c183)
        -   [Accelerometer](#org14e2ca2)
        -   [Gyroscope](#org58dfd33)
        -   [Magnetometer](#orga1c2318)
    -   [Heart Rate Monitor](#org1435a9a)
-   [@TODO](#orga187bdb)



<a id="org0df8c8f"></a>

# Sensors


<a id="orgf19c183"></a>

## IMU


<a id="org14e2ca2"></a>

### Accelerometer


<a id="org58dfd33"></a>

### Gyroscope


<a id="orga1c2318"></a>

### Magnetometer


<a id="org1435a9a"></a>

## Heart Rate Monitor


<a id="orga187bdb"></a>

# @TODO

adjust source parameter in Imu class for vb\_touch
adjust source parameter in Imu class for vb\_ef

